BBox class

A rectangular bounding box. Used for storage and for function arguments.

Constructors

BBox(double minLon, double minLat, double maxLon, double maxLat)
const
BBox.fromJson(List coords)

Properties

center → Point
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxLat → double
final
maxLon → double
final
minLat → double
final
minLon → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited