Point class

A single (lon, lat) point. It is used for storage and function arguments only, so it doesn't have any utility methods.

Constructors

Point(double lon, double lat)
const
Point.fromJson(List coords)

Properties

hashCode → int
The hash code for this object.
no setteroverride
lat → double
final
lon → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override